# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>   # noqa: E501

    The version of the OpenAPI document: 0.36.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from synctera_client_ng.models.spending_limit_with_time import SpendingLimitWithTime
from synctera_client_ng.models.spending_limits_transaction import SpendingLimitsTransaction

class SpendingLimits(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    day: Optional[SpendingLimitWithTime] = None
    description: Optional[StrictStr] = Field(None, description="User provided description on the spending limits")
    lifetime: Optional[SpendingLimitWithTime] = None
    month: Optional[SpendingLimitWithTime] = None
    transaction: Optional[SpendingLimitsTransaction] = None
    week: Optional[SpendingLimitWithTime] = None
    __properties = ["day", "description", "lifetime", "month", "transaction", "week"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SpendingLimits:
        """Create an instance of SpendingLimits from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of day
        if self.day:
            _dict['day'] = self.day.to_dict()
        # override the default output from pydantic by calling `to_dict()` of lifetime
        if self.lifetime:
            _dict['lifetime'] = self.lifetime.to_dict()
        # override the default output from pydantic by calling `to_dict()` of month
        if self.month:
            _dict['month'] = self.month.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction
        if self.transaction:
            _dict['transaction'] = self.transaction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of week
        if self.week:
            _dict['week'] = self.week.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SpendingLimits:
        """Create an instance of SpendingLimits from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SpendingLimits.parse_obj(obj)

        _obj = SpendingLimits.parse_obj({
            "day": SpendingLimitWithTime.from_dict(obj.get("day")) if obj.get("day") is not None else None,
            "description": obj.get("description"),
            "lifetime": SpendingLimitWithTime.from_dict(obj.get("lifetime")) if obj.get("lifetime") is not None else None,
            "month": SpendingLimitWithTime.from_dict(obj.get("month")) if obj.get("month") is not None else None,
            "transaction": SpendingLimitsTransaction.from_dict(obj.get("transaction")) if obj.get("transaction") is not None else None,
            "week": SpendingLimitWithTime.from_dict(obj.get("week")) if obj.get("week") is not None else None
        })
        return _obj

